@@ -1,7 +1,7 @@
 from simframe.integration.scheme import Scheme
 
 
-def _f_expl_1_euler(x0, Y0, dx, *args, **kwargs):
+def _f_expl_1_euler(x0, Y0, dx, *args, dYdx=None, **kwargs):
     """Explicit 1st-order Euler integration scheme
 
     Parameters
@@ -12,6 +12,8 @@ def _f_expl_1_euler(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    dYdx : Field, optional, default : None
+        Current derivative. Will be calculated, if not set.
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -26,7 +28,8 @@ def _f_expl_1_euler(x0, Y0, dx, *args, **kwargs):
     ---|---
        | 1 
     """
-    return Y0 + dx*Y0.derivative(x0, Y0)
+    k0 = Y0.derivative(x0, Y0) if dYdx is None else dYdx
+    return Y0 + dx*k0
 
 
 expl_1_euler = Scheme(
