@@ -7,7 +7,7 @@ b1 = 0.5
 c1 = 1.0
 
 
-def _f_expl_2_heun(x0, Y0, dx, *args, **kwargs):
+def _f_expl_2_heun(x0, Y0, dx, *args, dYdx=None, **kwargs):
     """Explicit 2nd-order Heun's method
 
     Parameters
@@ -18,6 +18,8 @@ def _f_expl_2_heun(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    dYdx : Field, optional, default : None
+        Current derivative. Will be calculated, if not set.
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -33,7 +35,7 @@ def _f_expl_2_heun(x0, Y0, dx, *args, **kwargs):
     -----|---------
          | 1/2 1/2
     """
-    k0 = Y0.derivative(x0, Y0)
+    k0 = Y0.derivative(x0, Y0) if dYdx is None else dYdx
     k1 = Y0.derivative(x0 + c1*dx, Y0 + a10*k0*dx)
 
     return Y0 + dx*(b0*k0 + b1*k1)
