@@ -6,7 +6,7 @@ b0, b1 = 1/4, 3/4
 c1 = 2/3
 
 
-def _f_expl_2_ralston(x0, Y0, dx, *args, **kwargs):
+def _f_expl_2_ralston(x0, Y0, dx, *args, dYdx=None, **kwargs):
     """Explicit 2nd-order Ralston's method
 
     Parameters
@@ -17,6 +17,8 @@ def _f_expl_2_ralston(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    dYdx : Field, optional, default : None
+        Current derivative. Will be calculated, if not set.
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -32,7 +34,7 @@ def _f_expl_2_ralston(x0, Y0, dx, *args, **kwargs):
     -----|---------
          | 1/4 3/4
     """
-    k0 = Y0.derivative(x0, Y0)
+    k0 = Y0.derivative(x0, Y0) if dYdx is None else dYdx
     k1 = Y0.derivative(x0 + c1*dx, Y0 + a10*k0*dx)
 
     return Y0 + dx*(b0*k0 + b1*k1)
