@@ -6,7 +6,7 @@ c1, c2 = 1/3, 2/3
 b0, b2 = 1/4, 3/4
 
 
-def _f_expl_3_heun(x0, Y0, dx, *args, **kwargs):
+def _f_expl_3_heun(x0, Y0, dx, *args, dYdx=None, **kwargs):
     """Explicit 3rd-order Heun's method
 
     Parameters
@@ -17,6 +17,8 @@ def _f_expl_3_heun(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    dYdx : Field, optional, default : None
+        Current derivative. Will be calculated, if not set.
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -33,7 +35,7 @@ def _f_expl_3_heun(x0, Y0, dx, *args, **kwargs):
     -----|-------------
          | 1/4  0  3/4
     """
-    k0 = Y0.derivative(x0, Y0)
+    k0 = Y0.derivative(x0, Y0) if dYdx is None else dYdx
     k1 = Y0.derivative(x0 + c1*dx, Y0 + a10*k0*dx)
     k2 = Y0.derivative(x0 + c2*dx, Y0 + a21*k1*dx)
 
