@@ -6,7 +6,7 @@ b0, b1, b2 = 1/6, 1/6, 2/3
 c2 = 1/2
 
 
-def _f_expl_3_ssprk(x0, Y0, dx, *args, **kwargs):
+def _f_expl_3_ssprk(x0, Y0, dx, *args, dYdx=None, **kwargs):
     """Explicit 3rd-order Strong Stability Preserving Runge-Kutta method
 
     Parameters
@@ -17,6 +17,8 @@ def _f_expl_3_ssprk(x0, Y0, dx, *args, **kwargs):
         Variable to be integrated at the beginning of scheme
     dx : IntVar
         Stepsize of integration variable
+    dYdx : Field, optional, default : None
+        Current derivative. Will be calculated, if not set.
     args : additional positional arguments
     kwargs : additional keyworda arguments
 
@@ -33,7 +35,7 @@ def _f_expl_3_ssprk(x0, Y0, dx, *args, **kwargs):
     -----|-------------
          | 1/6 1/6 2/3
     """
-    k0 = Y0.derivative(x0, Y0)
+    k0 = Y0.derivative(x0, Y0) if dYdx is None else dYdx
     k1 = Y0.derivative(x0 + dx, Y0 + k0 * dx)
     k2 = Y0.derivative(x0 + c2*dx, Y0 + (a20*k0 + a21*k1)*dx)
 
